@@ -8,13 +8,14 @@ from unittest.mock import MagicMock, patch
 import httpx
 import pytest
 from chromadb.api import AsyncClientAPI
-from chromadb.config import Settings
+from chromadb.api.models.AsyncCollection import AsyncCollection
 
 from vectorcode.cli_utils import Config
 from vectorcode.common import (
     get_client,
     get_collection,
     get_collection_name,
+    get_collections,
     get_embedding_function,
     start_server,
     try_server,
@@ -91,13 +92,17 @@ async def test_get_client():
         client = await get_client(config)
 
         assert isinstance(client, AsyncClientAPI)
-        MockAsyncHttpClient.assert_called_once_with(
-            host="test_host", port=1234, settings=Settings(anonymized_telemetry=False)
+        MockAsyncHttpClient.assert_called_once()
+        assert MockAsyncHttpClient.call_args.kwargs["host"] == "test_host"
+        assert MockAsyncHttpClient.call_args.kwargs["port"] == 1234
+        assert (
+            MockAsyncHttpClient.call_args.kwargs["settings"].anonymized_telemetry
+            is False
         )
 
         # Test with valid db_settings (only anonymized_telemetry)
         config = Config(
-            host="test_host",
+            host="test_host1",
             port=1234,
             db_path="test_db",
             db_settings={"anonymized_telemetry": True},
@@ -105,24 +110,30 @@ async def test_get_client():
         client = await get_client(config)
 
         assert isinstance(client, AsyncClientAPI)
-        MockAsyncHttpClient.assert_called_with(
-            host="test_host", port=1234, settings=Settings(anonymized_telemetry=True)
+        MockAsyncHttpClient.assert_called()
+        assert MockAsyncHttpClient.call_args.kwargs["host"] == "test_host1"
+        assert MockAsyncHttpClient.call_args.kwargs["port"] == 1234
+        assert (
+            MockAsyncHttpClient.call_args.kwargs["settings"].anonymized_telemetry
+            is True
         )
 
         # Test with multiple db_settings, including an invalid one.  The invalid one
         # should be filtered out inside get_client.
         config = Config(
-            host="test_host",
+            host="test_host2",
             port=1234,
             db_path="test_db",
             db_settings={"anonymized_telemetry": True, "other_setting": "value"},
         )
         client = await get_client(config)
         assert isinstance(client, AsyncClientAPI)
-        MockAsyncHttpClient.assert_called_with(
-            host="test_host",
-            port=1234,
-            settings=Settings(anonymized_telemetry=True),
+        MockAsyncHttpClient.assert_called()
+        assert MockAsyncHttpClient.call_args.kwargs["host"] == "test_host2"
+        assert MockAsyncHttpClient.call_args.kwargs["port"] == 1234
+        assert (
+            MockAsyncHttpClient.call_args.kwargs["settings"].anonymized_telemetry
+            is True
         )
 
 
@@ -213,6 +224,14 @@ async def test_get_collection():
     with patch("chromadb.AsyncHttpClient") as MockAsyncHttpClient:
         mock_client = MagicMock(spec=AsyncClientAPI)
         mock_collection = MagicMock()
+
+        # Clear the collection cache
+        from vectorcode.common import __COLLECTION_CACHE
+
+        __COLLECTION_CACHE.clear()
+
+        # Make get_collection raise ValueError to trigger get_or_create_collection
+        mock_client.get_collection.side_effect = ValueError("Collection not found")
         mock_collection.metadata = {
             "hostname": socket.gethostname(),
             "username": os.environ.get(
@@ -224,16 +243,13 @@ async def test_get_collection():
         MockAsyncHttpClient.return_value = mock_client
 
         collection = await get_collection(mock_client, config, make_if_missing=True)
-        assert collection == mock_collection
+        assert collection.metadata["hostname"] == socket.gethostname()
+        assert collection.metadata["username"] == os.environ.get(
+            "USER", os.environ.get("USERNAME", "DEFAULT_USER")
+        )
+        assert collection.metadata["created-by"] == "VectorCode"
         mock_client.get_or_create_collection.assert_called_once()
-
-    # Test raising ValueError if collection doesn't exist and make_if_missing is False
-    with patch("chromadb.AsyncHttpClient") as MockAsyncHttpClient:
-        mock_client = MagicMock(spec=AsyncClientAPI)
-        mock_client.get_collection.side_effect = ValueError("Collection not found")
-        MockAsyncHttpClient.return_value = mock_client
-        with pytest.raises(ValueError):
-            await get_collection(mock_client, config, make_if_missing=False)
+        mock_client.get_collection.side_effect = None
 
     # Test raising IndexError on hash collision.
     with patch("chromadb.AsyncHttpClient") as MockAsyncHttpClient:
@@ -242,6 +258,9 @@ async def test_get_collection():
             "Hash collision occurred"
         )
         MockAsyncHttpClient.return_value = mock_client
+        from vectorcode.common import __COLLECTION_CACHE
+
+        __COLLECTION_CACHE.clear()
         with pytest.raises(IndexError):
             await get_collection(mock_client, config, make_if_missing=True)
 
@@ -305,3 +324,84 @@ async def test_start_server():
 
             # Assert that the function returns the process
             assert process == mock_process
+
+
+@pytest.mark.asyncio
+async def test_get_collections():
+    # Mocking AsyncClientAPI and AsyncCollection
+    mock_client = MagicMock(spec=AsyncClientAPI)
+
+    # Mock successful get_collection
+    mock_collection1 = MagicMock(spec=AsyncCollection)
+    mock_collection1.metadata = {
+        "created-by": "VectorCode",
+        "username": os.environ.get("USER", os.environ.get("USERNAME", "DEFAULT_USER")),
+        "hostname": socket.gethostname(),
+    }
+
+    # collection with meta == None
+    mock_collection2 = MagicMock(spec=AsyncCollection)
+    mock_collection2.metadata = None
+
+    # collection with wrong "created-by"
+    mock_collection3 = MagicMock(spec=AsyncCollection)
+    mock_collection3.metadata = {
+        "created-by": "NotVectorCode",
+        "username": os.environ.get("USER", os.environ.get("USERNAME", "DEFAULT_USER")),
+        "hostname": socket.gethostname(),
+    }
+
+    # collection with wrong "username"
+    mock_collection4 = MagicMock(spec=AsyncCollection)
+    mock_collection4.metadata = {
+        "created-by": "VectorCode",
+        "username": "wrong_user",
+        "hostname": socket.gethostname(),
+    }
+
+    # collection with wrong "hostname"
+    mock_collection5 = MagicMock(spec=AsyncCollection)
+    mock_collection5.metadata = {
+        "created-by": "VectorCode",
+        "username": os.environ.get("USER", os.environ.get("USERNAME", "DEFAULT_USER")),
+        "hostname": "wrong_host",
+    }
+
+    mock_client.list_collections.return_value = [
+        "collection1",
+        "collection2",
+        "collection3",
+        "collection4",
+        "collection5",
+    ]
+    mock_client.get_collection.side_effect = [
+        mock_collection1,
+        mock_collection2,
+        mock_collection3,
+        mock_collection4,
+        mock_collection5,
+    ]
+
+    collections = [
+        collection async for collection in get_collections(mock_client)
+    ]  # call get_collections
+    assert len(collections) == 1
+    assert collections[0] == mock_collection1
+
+
+def test_get_embedding_function_fallback():
+    # Test with an invalid embedding function that causes AttributeError
+    config = Config(embedding_function="InvalidFunction", embedding_params={})
+    embedding_function = get_embedding_function(config)
+    assert "SentenceTransformerEmbeddingFunction" in str(type(embedding_function))
+
+
+@pytest.mark.asyncio
+async def test_wait_for_server_request_error():
+    # Mocking httpx.AsyncClient to raise a RequestError
+    with patch("httpx.AsyncClient") as mock_client:
+        mock_client.return_value.__aenter__.return_value.get.side_effect = (
+            httpx.RequestError("Simulated request error")
+        )
+        with pytest.raises(TimeoutError):
+            await wait_for_server("localhost", 9999, timeout=1)
